@@ -2,7 +2,7 @@ package InfluxDB::LineProtocol;
 use strict;
 use warnings;
 
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 
 # ABSTRACT: Write and read InfluxDB LineProtocol
 
@@ -69,8 +69,8 @@ sub data2line {
             # positive & negativ ints, exponentials, use Regexp::Common?
             $v !~ /^-?\d+(?:\.\d+)?(?:e-?\d+)?$/
             &&
-            # Regexp::Assemble->new->add(qw(t T true TRUE f F false FALSE))->re;
-            $v !~ /^(?^:(?:F(?:ALSE)?|f(?:alse)?|T(?:RUE)?|t(?:rue)?))$/
+            # perl 5.12 Regexp::Assemble->new->add(qw(t T true TRUE f F false FALSE))->re;
+            $v !~ /^(?:F(?:ALSE)?|f(?:alse)?|T(?:RUE)?|t(?:rue)?)$/
         )
         {
             $v =~ s/"/\\"/g;
@@ -89,7 +89,10 @@ sub line2data {
 
     $line =~ s/\\ /ESCAPEDSPACE/g;
     $line =~ s/\\,/ESCAPEDCOMMA/g;
-    my ( $key, $fields, $timestamp ) = split( / /, $line );
+    $line =~ s/\\"/ESCAPEDDBLQUOTE/g;
+
+    $line=~/^(.*?) (.*) (.*)$/;
+    my ($key, $fields, $timestamp) = ( $1, $2, $3);
 
     my ( $measurment, @taglist ) = split( /,/, $key );
     $measurment =~ s/ESCAPEDSPACE/ /g;
@@ -104,12 +107,17 @@ sub line2data {
     }
 
     my $values;
+    my @strings;
+    if ($fields =~ /"/) {
+        my $cnt=0;
+        $fields=~s/"(.*?)"/push(@strings, $1); 'ESCAPEDSTRING_'.$cnt++;/ge;
+    }
     foreach my $valset ( split( /,/, $fields ) ) {
         $valset =~ s/ESCAPEDSPACE/ /g;
         $valset =~ s/ESCAPEDCOMMA/,/g;
         my ( $k, $v ) = split( /=/, $valset );
-        $v =~ s/^"//;
-        $v =~ s/"$//;
+        $v =~ s/ESCAPEDSTRING_(\d+)/$strings[$1]/ge;
+        $v =~ s/ESCAPEDDBLQUOTE/"/g;
         $values->{$k} = $v;
     }
 
@@ -130,7 +138,7 @@ InfluxDB::LineProtocol - Write and read InfluxDB LineProtocol
 
 =head1 VERSION
 
-version 1.003
+version 1.004
 
 =head1 SYNOPSIS
 
